@@ -13,5 +13,5 @@ from trdb2py.plotly import (showAssetCandles, showHeatmap, showHeatmapWinRateInY
                             showBarWinRateInMonths, showBarWinRateInYears, showBarWinRate4Month,
                             showPNL, showPNLs, showPNLs2, showBarResponseRateInYears,
                             showAssetCandles2)
-from trdb2py.trdb2utils import analysisResult, getIndicatorInResult
+from trdb2py.trdb2utils import analysisResult, getIndicatorInResult, getFirstCtrlTs, buildPNLDataFrame
 import trdb2py.trading2_pb2
